{-# LANGUAGE OverloadedStrings #-}

module Gitea.Preview.Markdown where

import Control.Exception (throwIO)
import Data.Default (def)
import Data.Text (Text)
import Data.Text.Encoding (decodeUtf8')
import Text.Pandoc (Pandoc, PandocError, ReaderOptions(..), readMarkdown, runPure, handleError, pandocExtensions, writeHtml5String)

import qualified Data.ByteString as BS
import qualified Data.Text.IO as T

import Gitea.Preview.Markdown.Math
import Gitea.Preview.Markdown.Meta
import Gitea.Preview.Markdown.Signatures
import Gitea.Preview.Markdown.ChromaHighlight

main :: IO ()
main = do
    input <- decodeUtf8' <$> BS.getContents
    case input of
      Left err -> throwIO err
      Right text -> do
          pandoc <- handleError $ readMD text
          out <- handleError $ runPure $ writeHtml5String def $ pandocFilter pandoc
          T.putStr out

pandocFilter :: Pandoc -> Pandoc
pandocFilter = renderSignatures'
    . katexMath'
    . chromaHighlight'
    . renderMeta'

readMD :: Text -> Either PandocError Pandoc
readMD = runPure . readMarkdown def
    { readerStandalone = True
    , readerExtensions = pandocExtensions
    }
